Absolute

Struct Absolute 

pub struct Absolute {
    pub x: bool,
    pub y: bool,
    pub filter: bool,
    /* private fields */
}

Fields

x: bool

Set to false to disable X.

Disabling the X-axis will not allow regular tracking and is not recommended for typical applications.

y: bool

Set to false to disable Y.

Disabling the Y-axis will not allow regular tracking and is not recommended for typical applications.

filter: bool

Set to false to disable filter.

The Filter disable bit controls whether the filtering algorithm is applied to generated data. By default the hardware filters are enabled. Cirque does not recommend disabling hardware filtering.

Implementations

Source

impl Absolute

pub fn init<S: SpiDevice<u8>>( &self, spi: S, ) -> Result<Touchpad<S, Self>, S::Error>