Relative

Struct Relative 

pub struct Relative {
    pub x: bool,
    pub y: bool,
    pub filter: bool,
    pub swap_x_y: bool,
    pub glide_extend: bool,
    pub scroll: bool,
    pub secondary_tap: bool,
    pub taps: bool,
    pub intellimouse: bool,
}

Fields

x: bool

Set to false to disable X.

Disabling the X-axis will not allow regular tracking and is not recommended for typical applications.

y: bool

Set to false to disable Y.

Disabling the Y-axis will not allow regular tracking and is not recommended for typical applications.

filter: bool

Set to false to disable filter.

The Filter disable bit controls whether the filtering algorithm is applied to generated data. By default the hardware filters are enabled. Cirque does not recommend disabling hardware filtering.

swap_x_y: bool

Swap X & Y

glide_extend: bool

Enable GlideExtend®.

GlideExtend is Cirque’s patented motion extender technology that allows the user to continue the drag function when an edge is reached, by lifting and repositioning the finger.

scroll: bool

Enable scroll.

secondary_tap: bool

Enable secondary tap.

Secondary Taps allows a tap in the upper right corner (standard orientation) to simulate an activation of the secondary button.

taps: bool

If false, disables all taps.

Disabling all taps disables secondary taps, even if secondary tap is explicitly enabled.

intellimouse: bool

Enable Intellimouse.

Intellimouse enabled will change Pinnacle’s relative data packet to four bytes rather than three. The fourth byte (PacketByte_3) will report scroll data (referred to as wheel count).

Implementations

Source

impl Relative

pub fn init<S: SpiDevice<u8>>( &self, spi: S, ) -> Result<Touchpad<S, Self>, S::Error>