PowerMode

Enum PowerMode 

pub enum PowerMode {
    Active,
    Sleep,
    Shutdown,
}
Pinnacle has four power modes - Active (touch detected), Idle (no touch), Low Power/ Sleep (lower power after ~ 5 seconds of inactivity) and Shutdown/Standby (no data reported).

Variants



Active

By default, Pinnacle toggles between Active and Idle mode. Pinnacle is in Active mode when a touch is detected (that is, a finger or stylus is present and is moving or tapping on the trackpad). The measurement system is active and data packets are being created and then sent to the host. Active mode begins as soon as a touch is detected. Idle mode is entered when the finger has been removed and there are no data packets to be sent. While in Idle mode, Pinnacle wakes every 10 milliseconds to check for a touch.



Sleep

Enabling sleep mode will cause Pinnacle to go into a low power mode (around 50 μA) within 5 seconds of no touch detection. While in sleep mode, Pinnacle will wake within 300 ms to report any detection of a finger/stylus.



Shutdown

Shutdown/Standby mode is a very low power mode and Pinnacle does not track touch in this mode.