pub struct Absolute {
pub x: bool,
pub y: bool,
pub filter: bool,
/* private fields */
}Fields
x: boolSet to false to disable X.
Disabling the X-axis will not allow regular tracking and is not recommended for typical applications.
y: boolSet to false to disable Y.
Disabling the Y-axis will not allow regular tracking and is not recommended for typical applications.
filter: boolSet to false to disable filter.
The Filter disable bit controls whether the filtering algorithm is applied to generated data. By default the hardware filters are enabled. Cirque does not recommend disabling hardware filtering.
Implementations